@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -57,7 +57,7 @@ Derivative::Derivative(ActionExtension* extension) : Action(extension) {
                        <li> Derivative along Z axis \
                    </ul> \
 				   ");
-    setComponent("ImageComponent");
+    setComponentClassName("ImageComponent");
 
     // Setting classification family and tags
     this->setFamily("ITK Filter");
