@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -40,7 +40,7 @@ GradientMagnitude::GradientMagnitude(ActionExtension* extension) : Action(extens
     setName("Gradient Magnitude");
     setDescription("<br>The <i>magnitude of the image gradient</i> is extensively used in image analysis, mainly to help in the determination of object contours and the separation of homogeneous regions. <br> \
 				   <b>The Gradient Magnitude filter</b> computes the magnitude of the image gradient at each pixel location using a simple finite differences approach. (<i>source: ITK Developer's Guide)</i><br>  ");
-    setComponent("ImageComponent");
+    setComponentClassName("ImageComponent");
 
     // Setting classification family and tags
     this->setFamily("ITK Filter");
