@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -43,7 +43,7 @@ LaplacianRecursiveGaussian::LaplacianRecursiveGaussian(ActionExtension* extensio
     // Setting name, description and input component
     setName("Laplacian Filter With Smoothing");
     setDescription("<br/>Computes the <b>Laplacian of Gaussian (LoG)</b> of an image by convolution with the second derivative of a Gaussian.<br/><br/> This filter is implemented using the recursive gaussian filters.");
-    setComponent("ImageComponent");
+    setComponentClassName("ImageComponent");
 
     // Setting classification family and tags
     this->setFamily("ITK Filter");
