@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -46,7 +46,7 @@ SobelEdgeDetection::SobelEdgeDetection(ActionExtension* extension) : Action(exte
     setName("Sobel Edge Detection");
     setDescription("<br>A 2D or 3D <b>edge detection using the Sobel operator</b>.<br> \
                    This filter uses the Sobel operator to calculate the image gradient and then finds the magnitude of this gradient vector. The Sobel gradient magnitude (square-root sum of squares) is an indication of edge strength..<br>");
-    setComponent("ImageComponent");
+    setComponentClassName("ImageComponent");
 
     // Setting classification family and tags
     this->setFamily("ITK Filter");
