@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -46,7 +46,7 @@ ManualThreshold::ManualThreshold(ActionExtension* extension) : Action(extension)
                    <li>low threshold &lt; scalar value &lt; high threshold &gt; white (255) </li> \
                    <li>scalar value &lt; low threshold OR scalar value &gt; high threshold &gt; black (0)</li> \
                    </ul>");
-    setComponent("ImageComponent");
+    setComponentClassName("ImageComponent");
 
     // Setting classification family and tags
     setFamily("ITK Segmentation");
