@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -27,6 +27,7 @@
 #include <ImageOrientationHelper.h>
 #include <Log.h>
 #include "DicomParser.h"
+#include "DicomSeries.h"
 
 // Qt includes
 #include <QDir>
@@ -90,11 +91,12 @@ DicomComponent::DicomComponent(DicomSeries* dicomSeries) : ImageComponent("") {
 
     // get image orientation information
     // we need to get the rotation matrix from tag "Direct cos angle"
-    ImageOrientationHelper::PossibleImageOrientations orientation = readDirectCosinesAngle(files);
+    ImageOrientationHelper::PossibleImageOrientations orientationFromCos = readDirectCosinesAngle(files);
 
 
     // get the image position orientation
     // TODO read the tag (0018, 5100) Patient position
+    // https://dicom.nema.org/medical/Dicom/2016e/output/chtml/part03/sect_C.7.3.html#sect_C.7.3.1.1.2
 
     // create image data corresponding to the component
     imageReader = vtkSmartPointer<vtkGDCMImageReader>::New();
@@ -117,7 +119,8 @@ DicomComponent::DicomComponent(DicomSeries* dicomSeries) : ImageComponent("") {
     // Update Z Spacing using a VTK pipeline
     vtkSmartPointer<vtkImageChangeInformation> imageInfoChanger = vtkSmartPointer<vtkImageChangeInformation>::New();
     imageInfoChanger->SetInputData(rawData); //translatedData);
-
+    double origin[3] = {0.0, 0.0, 0.0}; //We set the image origin at (0,0,0)
+    imageInfoChanger->SetOutputOrigin(origin);
     imageInfoChanger->SetOutputSpacing(spacing[0], spacing[1], zSpacing);
     imageInfoChanger->Update();
 
@@ -133,11 +136,33 @@ DicomComponent::DicomComponent(DicomSeries* dicomSeries) : ImageComponent("") {
     flipYFilter->SetInputConnection(imageInfoChanger->GetOutputPort());
     flipYFilter->Update();
 
-    /// TODO Retrieve image position patient information
+    // Get DICOM patient position and orientation and set it as this component's frame transform
+    double* position = imageReader->GetImagePositionPatient();
+    double* orientation = imageReader->GetImageOrientationPatient();
 
-    // put back to the origin
+    double* xdir = &orientation[0];
+    double* ydir = &orientation[3];
+    double  zdir[3];
+    vtkMath::Cross(xdir, ydir, zdir);
+    vtkSmartPointer<vtkMatrix4x4> affineMatrix = vtkSmartPointer<vtkMatrix4x4>::New();
+
+    for (int i = 0; i < 3; i++) {
+        affineMatrix->Element[i][0] = xdir[i];
+        affineMatrix->Element[i][1] = ydir[i];
+        affineMatrix->Element[i][2] = zdir[i];
+        affineMatrix->Element[i][3] = position[i];
+    }
+
+    // get the processed image (flipped and with correct z-spacing)
     vtkSmartPointer<vtkImageData> image = flipYFilter->GetOutput();
-    setImageData(image, false, orientation);
+    setImageData(image, false);
+
+    //apply the affine matrix to the image
+    vtkSmartPointer<vtkTransform> transform = vtkSmartPointer<vtkTransform>::New();
+    transform->SetMatrix(affineMatrix);
+    transform->Update();
+
+    setTransform(transform);
 
     // Wait for the LUT update in CamiTK and / or support for color image
     if (getLut()) { // sometimes ImageComponent happens not to have a lut, strange behaviour
