@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -26,9 +26,8 @@
 #ifndef DICOMCOMPONENT_H
 #define DICOMCOMPONENT_H
 
-#include <QObject>
-
 #include <ImageComponent.h>
+#include "DicomComponentAPI.h"
 
 class DicomSeries;
 class vtkGDCMImageReader;
@@ -37,12 +36,13 @@ class vtkGDCMImageReader;
  * @ingroup group_cepimaging_components_dicom
  *
  * @brief
- * DICOM Component represents a volumic image of a DICOM SERIES with its corresponding tags information (as CamiTK properties).
+ * DICOM Component represents a volumic image of a DICOM SERIES with its
+ * corresponding tags information (as CamiTK properties).
  * This class is part of the MODEL (in the MVP pattern) of the DICOM COMPONENT.
  *
- * @note This component uses GDCM >= 2.2 library.
+ * @note This component requires GDCM >= 2.2 library.
  */
-class DicomComponent : public camitk::ImageComponent {
+class DICOM_COMPONENT_API DicomComponent : public camitk::ImageComponent {
 
     Q_OBJECT
 
