@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -29,17 +29,13 @@
 #include "DicomDialog.h"
 #include "DicomDialogEntry.h"
 #include "DicomSeries.h"
-#include <Application.h>
-
-// include generated components headers
 #include "DicomComponent.h"
 
 // Qt stuff
 #include <QFileInfo>
 
-// GDCM includes
-#include <gdcmScanner.h>
-#include <gdcmIPPSorter.h>
+// change cursor
+#include <QApplication>
 
 using namespace camitk;
 
@@ -76,6 +72,7 @@ Component* DicomComponentExtension::open(const QString& path) {
     QApplication::restoreOverrideCursor();
 
     // Open each selected Dicom as a component
+    QSet<DicomSeries*> openedSeries;
     if (!seriesDialogEntries.isEmpty()) {
         foreach (DicomDialogEntry* entry, seriesDialogEntries) {
             // Find the corresponding Dicom Series in the List
@@ -83,17 +80,28 @@ Component* DicomComponentExtension::open(const QString& path) {
                 if ((series->getStudyName() == entry->getStudyName()) &&
                         (series->getSeriesName() == entry->getSeriesName())) {
                     lastOpenedComponent = new DicomComponent(series);
-                    break;
-                }
-                else {
-                    delete series;
+                    openedSeries.insert(series);
                 }
             }
-
         }
     }
+    //Cleanup
+    for (DicomSeries* series : seriesParsed) {
+        if (!openedSeries.contains(series)) {
+            delete series;
+        }
+    }
+    seriesParsed.clear();
+
+    for (DicomDialogEntry* entry : seriesDialogEntries) {
+        delete entry;
+    }
     seriesDialogEntries.clear();
 
+    delete dialog;
+
+
+
 
     return lastOpenedComponent;
 }
