@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -26,9 +26,7 @@
 #ifndef DICOMCOMPONENTEXTENSION_H
 #define DICOMCOMPONENTEXTENSION_H
 
-#include <QObject>
-
-#include<ComponentExtension.h>
+#include <ComponentExtension.h>
 
 namespace camitk {
 class Component;
@@ -36,8 +34,7 @@ class Component;
 
 class DicomDialog;
 class DicomDialogEntry;
-
-#include "DicomSeries.h"
+class DicomSeries;
 
 
 /**
@@ -52,7 +49,7 @@ class DicomDialogEntry;
 class DicomComponentExtension : public camitk::ComponentExtension {
     Q_OBJECT
     Q_INTERFACES(camitk::ComponentExtension)
-    Q_PLUGIN_METADATA(IID "fr.imag.camitk.imaging.component.dicom")
+    Q_PLUGIN_METADATA(IID "fr.imag.camitk.sdk.component.dicom")
 
 public:
     /// Constructor
@@ -108,5 +105,5 @@ private:
 
 };
 
-#endif // DICOMCOMPONENTEXTENSION
+#endif // DICOMCOMPONENTEXTENSION_H
 
