@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -69,13 +69,6 @@ public:
     void setPatientName(QString name);
     ///@}
 
-    /// Get the number of item to display for the corresponding DicomTableWidgetItem class
-    /// This is used to set number of Column in the Dialog
-    static int numberOfItems() {
-        return 5;
-    }
-
-
 private:
 
     /// Is this SERIES selected for opening?
