@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -24,6 +24,7 @@
  ****************************************************************************/
 // CamiTK includes
 #include "DicomParser.h"
+#include "DicomSeries.h"
 #include <Log.h>
 
 // GDCM includes
@@ -52,7 +53,7 @@ QList<DicomSeries*> DicomParser::parseDirectory(const QString& directory) {
     dicomImageScanner.AddTag(tagPixelData);
     dicomImageScanner.Scan(fileNames);
 
-    CAMITK_TRACE_ALT(tr("Parsing files for DICOM image files"))
+    CAMITK_TRACE_ALT(QObject::tr("Parsing files for DICOM image files"))
     foreach (std::string file, dicomImageScanner.GetFilenames()) {
         // 1st check the file is a valid DICOM file
         if (dicomImageScanner.IsKey(file.c_str())) {
@@ -60,11 +61,11 @@ QList<DicomSeries*> DicomParser::parseDirectory(const QString& directory) {
             gdcm::Scanner::TagToValue const& ttv = dicomImageScanner.GetMapping(file.c_str());
             gdcm::Scanner::TagToValue::const_iterator it = ttv.find(tagPixelData);
             if (it != ttv.end()) {
-                CAMITK_TRACE_ALT(tr("%1 is a DICOM image file").arg(QString::fromStdString(file)))
+                CAMITK_TRACE_ALT(QObject::tr("%1 is a DICOM image file").arg(QString::fromStdString(file)))
                 imageFileNames.push_back(file);
             }
             else {
-                CAMITK_TRACE_ALT(tr("%1 is a DICOM file WITHOUT PixelData information").arg(QString::fromStdString(file)))
+                CAMITK_TRACE_ALT(QObject::tr("%1 is a DICOM file WITHOUT PixelData information").arg(QString::fromStdString(file)))
             }
         }
         else {
