@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -26,19 +26,11 @@
 #ifndef DICOMPARSER_H
 #define DICOMPARSER_H
 
-// CamiTK includes
-#include "DicomSeries.h"
+class DicomSeries;
 
-// Qt includes
-#include <QMap>
 #include <QList>
-#include <QString>
-#include <QCoreApplication>
-
-// C++ includes
-#include <cstdlib>
-#include <vector>
-
+#include <QDate>
+#include <QTime>
 
 /**
  * @ingroup group_cepimaging_components_dicom
@@ -49,9 +41,6 @@
  *
  */
 class DicomParser {
-
-    Q_DECLARE_TR_FUNCTIONS(DicomParser)
-
 public:
 
     DicomParser() = default;
