@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -52,11 +52,11 @@ using namespace camitk;
 
 // -------------------- GenerateModel --------------------
 GenerateModel::GenerateModel(ActionExtension* extension) : Action(extension) {
-    this->setName("Generate Model");
-    this->setDescription("Generates a model from a mesh: mml, pml and corresponding lml are generated.<p>The current points selected by picking (<tt>Picked Selection</tt>) will be considered as fixed nodes.");
-    this->setComponent("MeshComponent");
-    this->setFamily("Mesh Processing");
-    this->addTag("Build Biomechanical Model");
+    setName("Generate Model");
+    setDescription("Generates a model from a mesh: mml, pml and corresponding lml are generated.<p>The current points selected by picking (<tt>Picked Selection</tt>) will be considered as fixed nodes.");
+    setComponentClassName("MeshComponent");
+    setFamily("Mesh Processing");
+    addTag("Build Biomechanical Model");
 
     addParameter(new Property("Selection Is Constrained", true, "Use the current point selection to add a null displacement constraint to the model. If this is true, all the currently selected nodes will be fixed during the simulation", ""));
 
@@ -124,7 +124,7 @@ void GenerateModel::saveSOFAFile(QString baseFilename) {
     QString mshFilename = baseFilename + "-model.msh";
     QVector3D gravity = property("Gravity").value<QVector3D>();
 
-    ofstream scnFile(SOFAFileName.toUtf8());
+    std::ofstream scnFile(SOFAFileName.toUtf8());
 
     scnFile << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>" << endl;
     scnFile << "<!-- Created by " << Core::shortVersion << " -->" << endl;
@@ -185,7 +185,7 @@ void GenerateModel::saveMMLFiles(QString baseFilename) {
         l.addLoad(t);
 
         lmlFilename = baseFilename + "-boundary-condition.lml";
-        ofstream lmlofs(lmlFilename.toStdString().c_str());
+        std::ofstream lmlofs(lmlFilename.toStdString().c_str());
         l.xmlPrint(lmlofs);
         lmlofs.close();
     }
@@ -232,7 +232,7 @@ void GenerateModel::saveMMLFiles(QString baseFilename) {
     map[""].schema = "";
 
     QString mmlFilename = baseFilename + "-model.mml";
-    ofstream mmlofs(mmlFilename.toStdString().c_str());
+    std::ofstream mmlofs(mmlFilename.toStdString().c_str());
     mml::monitoringIn(mmlofs, mmlIn, map);
     mmlofs.close();
 
@@ -265,7 +265,7 @@ void GenerateModel::saveMMLFiles(QString baseFilename) {
         }
 
         // reopen for rewrite
-        ofstream pmlofs(completePmlFilename.toStdString().c_str(), std::ios_base::trunc);
+        std::ofstream pmlofs(completePmlFilename.toStdString().c_str(), std::ios_base::trunc);
         pml->xmlPrint(pmlofs);
         pmlofs.close();
 
