@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -39,7 +39,7 @@ SimulationDialog::SimulationDialog(ActionExtension* extension) : Action(extensio
     // Setting name, description and input component
     setName("Simulation Dialog");
     setDescription("Show MML Simulation Dialog");
-    setComponent("MMLComponent");
+    setComponentClassName("MMLComponent");
 
     // Setting classification family and tags
     setFamily("Modeling");
