@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -42,7 +42,7 @@ CreateSC::CreateSC(ActionExtension* extension) : Action(extension) {
 
     this->setName("Create Structural Component From Selection");
     this->setDescription("Generates a Structural Component from a given bounding box or current PML explorer selection");
-    this->setComponent("PMLComponent");
+    this->setComponentClassName("PMLComponent");
     this->setFamily("Physical Model");
     this->addTag("CreateSC");
     this->addTag("Select");
