@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -37,7 +37,7 @@ PMLExplorerAction::PMLExplorerAction(ActionExtension* extension) : Action(extens
     // Setting name, description and input component
     setName("Explore PML Content");
     setDescription("This action aims at exploring inner PML information (atoms, cells and components). Features a specific Qt explorer.");
-    setComponent("PMLComponent");
+    setComponentClassName("PMLComponent");
 
     // Setting classification family and tag
     setFamily("Physical Model");
