@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -77,7 +77,7 @@ MMLComponent::MMLComponent(const QString& fileName) : Component(fileName, QFileI
 
             exportedMml = file;
 
-            ofstream ofs(exportedMml.toStdString().c_str());
+            std::ofstream ofs(exportedMml.toStdString().c_str());
             mml::monitoringIn(ofs, mmlIn, map);
             // to make sure it will be saved again
             setModified();
