@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -46,7 +46,7 @@ Statistics::Statistics(Monitor* monitor, MMLComponent* manager): MMLMonitorDispl
     item->setText(("Statistics"));
     t->setHorizontalHeaderItem(j, item);
     table = new QTableWidget;
-    table->setEditTriggers(nullptr);
+    table->setEditTriggers(QAbstractItemView::NoEditTriggers);
     t->setCellWidget(line, j, table);
 }
 
