@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -47,7 +47,7 @@ Tabular::Tabular(Monitor* monitor, MMLComponent* manager): MMLMonitorDisplay(mon
     item->setText(("Tabular"));
     t->setHorizontalHeaderItem(j, item);
     table = new QTableWidget;
-    table->setEditTriggers(nullptr);
+    table->setEditTriggers(QAbstractItemView::NoEditTriggers);
     t->setCellWidget(line, j, table);
     table->installEventFilter(this);
 }
