@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -38,7 +38,7 @@ using namespace camitk;
 ImageLutAction::ImageLutAction(ActionExtension* extension) : Action(extension) {
     setName("Image Look Up Table");
     setDescription("Modify the LUT of an image components");
-    setComponent("ImageComponent");
+    setComponentClassName("ImageComponent");
     setFamily("View");
     addTag("LUT");
 }
