@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -295,7 +295,7 @@ void ImageLutWidget::drawGraphics() {
         colorGradient.setColorAt(double(i) / double(nbOfColors), QColor::fromRgbF(color[0], color[1], color[2]));
     }
 
-    pen.setColor(palette().background().color());
+    pen.setColor(palette().window().color());
     brush = QBrush(colorGradient);
     ui.histogramGraphicsView->scene()->addRect(QRectF(topLeft, bottomRight), pen, brush);
 
