@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -37,7 +37,7 @@ using namespace camitk;
 MultiPicking::MultiPicking(ActionExtension* extension) : Action(extension) {
     setName("Multiple Picking");
     setDescription(tr("Action to manage several pixel points in an image (coordinates and index)."));
-    setComponent("ImageComponent");
+    setComponentClassName("ImageComponent");
     setFamily("Image Processing");
     addTag(tr("Picking"));
     addTag(tr("Select Pixels"));
