@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -162,7 +162,7 @@ void PickedPixelMap::savePixelList(QString fileName) {
 
     // write the points in a csv file
     // the form is : index (int) | i (int) | j (int) | k (int) | x (double) | y (double) | z (double) |
-    ofstream myFile;
+    std::ofstream myFile;
 
     // open the file to write
     char separator = ',';
