@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -42,7 +42,7 @@ PixelColorChanger::PixelColorChanger(ActionExtension* extension) : Action(extens
                    <li>A size of 2 corresponds to 3 pixels in the slice, in the aim to always keep the picked pixel as the center.  <br />(Size 3-> 5pix; 4->7pix...)</li></ul>\
 <br /> Compatible with this pixel types formats :[unsigned] short / float / double / char"));
 
-    setComponent("ImageComponent");
+    setComponentClassName("ImageComponent");
 
     // Setting classification family and tags
     this->setFamily("Image Processing");
