@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -34,7 +34,7 @@ ShowAxialSliceIn3D::ShowAxialSliceIn3D(ActionExtension* extension) : Action(exte
     setName("Show Axial Slice In 3D");
     setEmbedded(false);
     setDescription(tr("Toggle display of the axial slice in 3D"));
-    setComponent("ImageComponent");
+    setComponentClassName("ImageComponent");
 
     // Setting classification family and tags
     setFamily("View");
