@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -35,7 +35,7 @@ ShowCoronalSliceIn3D::ShowCoronalSliceIn3D(ActionExtension* extension) : Action(
     setName("Show Coronal Slice In 3D");
     setEmbedded(false);
     setDescription(tr("Toggle display of the coronal slice(s) in 3D"));
-    setComponent("ImageComponent");
+    setComponentClassName("ImageComponent");
 
     // Setting classification family and tags
     setFamily("View");
