@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -34,7 +34,7 @@ ShowImageIn3D::ShowImageIn3D(ActionExtension* extension) : Action(extension) {
     setName("Show Image In 3D");
     setEmbedded(false);
     setDescription(tr("Shows the Image Volume in 3D viewer"));
-    setComponent("ImageComponent");
+    setComponentClassName("ImageComponent");
     // TODO: set a small icon with Axial/Coronal/Sagittal views in 3D
 
     // Setting classification family and tags
