@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -35,7 +35,7 @@ SingleAcquisition2DAction::SingleAcquisition2DAction(ActionExtension* extension)
     // Setting name, description and input component
     setName("singleAcquisition2D");
     setDescription("acquire one 2D ImageComponent by the device");
-    setComponent("ImageAcquisitionComponent");
+    setComponentClassName("ImageAcquisitionComponent");
 
     // Setting classification family and tags
     setFamily("Image Acquisition");
