@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -35,7 +35,7 @@ StartImaging2DAction::StartImaging2DAction(ActionExtension* extension) : Action(
     // Setting name, description and input component
     setName("startImaging2D");
     setDescription("start the 2D acquisition done with the device (i.e : running a acquisition in live mode...)");
-    setComponent("ImageAcquisitionComponent");
+    setComponentClassName("ImageAcquisitionComponent");
 
     // Setting classification family and tags
     setFamily("Image Acquisition");
