@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -35,7 +35,7 @@ StopImaging3DAction::StopImaging3DAction(ActionExtension* extension) : Action(ex
     // Setting name, description and input component
     setName("stopImaging3D");
     setDescription("stop the 3D continuous acquisition performed by the device");
-    setComponent("ImageAcquisitionComponent");
+    setComponentClassName("ImageAcquisitionComponent");
 
     // Setting classification family and tags
     setFamily("Image Acquisition");
