@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -42,7 +42,7 @@ CenterMesh::CenterMesh(ActionExtension* extension) : Action(extension) {
     setName("Center Mesh");
     setEmbedded(false);
     setDescription("Center current mesh component (at the end the barycenter of the mesh is in (0,0,0)");
-    setComponent("MeshComponent");
+    setComponentClassName("MeshComponent");
     setFamily("Basic Mesh");
     addTag("Transform");
     addTag("Translate");
