@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -37,7 +37,7 @@ ChangeColor::ChangeColor(ActionExtension* extension) : Action(extension) {
     setName("Change Color");
     setEmbedded(false);
     setDescription(tr("Change the surface, wireframe or points colors of objects"));
-    setComponent("MeshComponent");
+    setComponentClassName("MeshComponent");
     setFamily("Basic Mesh");
     setIcon(QPixmap(":/changeColor"));
     addTag(tr("Color"));
@@ -70,7 +70,6 @@ Action::ApplyStatus ChangeColor::apply() {
         return SUCCESS;
     }
     else {
-        CAMITK_WARNING(tr("Invalid color. Action Aborted."))
         return ABORTED;
     }
 }
