@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -42,7 +42,7 @@ using namespace camitk;
 MeshPicking::MeshPicking(ActionExtension* extension) : Action(extension) {
     setName("Basic Mesh Picking");
     setDescription("Pick a mesh to retrieve point/cell information from the mesh");
-    setComponent("MeshComponent");
+    setComponentClassName("MeshComponent");
     setFamily("Basic Mesh");
     addTag("Picking");
 
