@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -44,7 +44,7 @@ RigidTransform::RigidTransform(ActionExtension* extension) : Action(extension) {
     setName("Rigid Transform");
     setEmbedded(false);
     setDescription("Rigid transformation of Components");
-    setComponent("MeshComponent");
+    setComponentClassName("MeshComponent");
     setFamily("Basic Mesh");
     addTag("Transform");
     addTag("Translate");
