@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -42,7 +42,7 @@ using namespace camitk;
 GridTopology::GridTopology(ActionExtension* extension) : Action(extension) {
     setName("Grid Topology");
     setDescription("Build a regular grid");
-    setComponent("");    // empty component: it does not need any data to be triggered
+    setComponentClassName("");    // empty component: it does not need any data to be triggered
     setFamily("Mesh Processing");
     addTag("Build Grid");
 
@@ -93,6 +93,7 @@ Action::ApplyStatus GridTopology::apply() {
             }
 
     vtkSmartPointer<vtkUnstructuredGrid> grid = vtkSmartPointer<vtkUnstructuredGrid>::New();
+    grid->Allocate();
     grid->SetPoints(points);
 
     // build grid
