@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -47,7 +47,7 @@ SphereTopology::SphereTopology(ActionExtension* extension) : Action(extension) {
     setName("Sphere Topology");
     setEmbedded(true);
     setDescription("Build a sphere");
-    setComponent(""); // empty component: it does not need any data to be triggered
+    setComponentClassName(""); // empty component: it does not need any data to be triggered
     setFamily("Mesh Processing");
     addTag("Build Sphere");
 
