@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -42,7 +42,7 @@ AppendMeshes::AppendMeshes(camitk::ActionExtension* ext) : Action(ext) {
 
     this->setName("Append Meshes");
     this->setDescription(QString(tr("Append several meshes in one mesh.")));
-    this->setComponent("MeshComponent");
+    this->setComponentClassName("MeshComponent");
     this->setFamily("Mesh Processing");
 
     Property* mergePointsProperty = new Property(tr("Merge Points"), true, tr("Define if close points are merged"), "");
