@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -52,7 +52,7 @@ ExportAsMDL::ExportAsMDL(ActionExtension* extension) : Action(extension) {
     // Setting name, description and input component
     setName("Export As MDL");
     setDescription(tr("Export As MDL (an old legacy file format from early CAMI devices). This is kept for historical reason only."));
-    setComponent("MeshComponent");
+    setComponentClassName("MeshComponent");
 
     // Setting classification family and tags
     setFamily("Mesh Processing");
