@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -39,7 +39,7 @@ using namespace camitk;
 ExtractSurface::ExtractSurface(ActionExtension* extension) : Action(extension) {
     this->setName("Extract Surface");
     this->setDescription(tr("Extract Surface from Volumetric Mesh"));
-    this->setComponent("MeshComponent");
+    this->setComponentClassName("MeshComponent");
     this->setFamily("Mesh Processing");
     this->addTag(tr("ExtractSurface"));
 }
