@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -47,7 +47,7 @@ ICPRegistration::ICPRegistration(camitk::ActionExtension* ext) : Action(ext) {
                          QString(tr("<li> The first one is the source mesh (the one to be registered) </li>")) +
                          QString(tr("<li> The second one is the target mesh </li>")) +
                          QString("</ul>"));
-    this->setComponent("MeshComponent");
+    this->setComponentClassName("MeshComponent");
     this->setFamily("Mesh Processing");
     this->addTag(tr("Registration"));
     this->addTag(tr("CPI"));
