@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -48,7 +48,7 @@ SaveDisplacementFromTransformation::SaveDisplacementFromTransformation(ActionExt
     setName("Save Displacement From Transformation");
     setDescription(tr("Save the displacement from the last translation in a text file. Alternatively, load a transformation from \
                    a text file and apply it on the selected Mesh component."));
-    setComponent("MeshComponent");
+    setComponentClassName("MeshComponent");
 
     // Setting classification family and tags
     setFamily("Mesh Processing");
