@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -50,7 +50,7 @@ WarpOut::WarpOut(ActionExtension* extension) : Action(extension) {
     // Setting name, description and input component
     setName("Warp Out");
     setDescription(tr("Move the outside points along the normal in order to thicken a volumic mesh (works only with closed- centered- mesh)."));
-    setComponent("MeshComponent");
+    setComponentClassName("MeshComponent");
 
     // Setting classification family and tags
     setFamily("Mesh Processing");
@@ -80,9 +80,11 @@ Action::ApplyStatus WarpOut::apply() {
 
     if (vtkUnstructuredGrid::SafeDownCast(targetMesh->getPointSet())) {
         resultPointSet = vtkSmartPointer<vtkUnstructuredGrid>::New();
+        vtkUnstructuredGrid::SafeDownCast(resultPointSet)->Allocate();
     }
     else if (vtkPolyData::SafeDownCast(targetMesh->getPointSet())) {
         resultPointSet = vtkSmartPointer<vtkPolyData>::New();
+        vtkPolyData::SafeDownCast(resultPointSet)->Allocate();
     }
     else {
         QApplication::restoreOverrideCursor();
