@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -109,7 +109,7 @@ Action::ApplyStatus ActionState::applyAction() {
 
     if (myAction != NULL) {
         if (logStream != nullptr) {
-            (*logStream) << "\t\t<applyAction>" << endl;
+            (*logStream) << "\t\t<applyAction>" << Qt::endl;
         }
 
         // apply the action
@@ -122,7 +122,7 @@ Action::ApplyStatus ActionState::applyAction() {
         namesIt = outputComponentNames.constBegin();
 
         if ((logStream != nullptr) && (outputComps.size() > 0)) {
-            (*logStream) << "\t\t\t<outputs>" << endl;
+            (*logStream) << "\t\t\t<outputs>" << Qt::endl;
         }
 
         for (outIt = outputComps.constBegin(); outIt != outputComps.constEnd(); ++outIt) {
@@ -136,21 +136,21 @@ Action::ApplyStatus ActionState::applyAction() {
 
                     if (logStream != NULL) {
                         (*logStream) << "\t\t\t\t<component name='" ;
-                        (*logStream) << compName << "' type='" << compType << "'/>" << endl;
+                        (*logStream) << compName << "' type='" << compType << "'/>" << Qt::endl;
                     }
                 }
             }
         }
 
         if ((logStream != NULL) && (outputComps.size() > 0)) {
-            (*logStream) << "\t\t\t</outputs>" << endl;
+            (*logStream) << "\t\t\t</outputs>" << Qt::endl;
         }
 
         Application::refresh();
 
         if (logStream != nullptr) {
-            (*logStream) << "\t\t\t<status>" << Action::getStatusAsString(status) << "</status>" << endl;
-            (*logStream) << "\t\t</applyAction>" << endl;
+            (*logStream) << "\t\t\t<status>" << Action::getStatusAsString(status) << "</status>" << Qt::endl;
+            (*logStream) << "\t\t</applyAction>" << Qt::endl;
         }
     }
 
@@ -206,17 +206,16 @@ void ActionState::onEntry(QEvent* event) {
 
     if (logStream != nullptr) {
         //-- log the start
-        startTime = new QTime();
-        startTime->start();
+        actionTimer = QTime::currentTime();
 
-        (*logStream) << "\t<state>" << endl;
-        (*logStream) << "\t\t<name>" << this->name << "</name>" << endl;
-        (*logStream) << "\t\t<startTime>" << startTime->toString("hh:mm:ss:zzz") << "</startTime>" << endl;
+        (*logStream) << "\t<state>" << Qt::endl;
+        (*logStream) << "\t\t<name>" << this->name << "</name>" << Qt::endl;
+        (*logStream) << "\t\t<startTime>" << actionTimer.toString("hh:mm:ss:zzz") << "</startTime>" << Qt::endl;
 
         //-- prepare the action and GUI
         if (myAction != nullptr) {
             // log the action entry
-            (*logStream) << "\t\t<actionName>" << myAction->getName() << "</actionName>" << endl;
+            (*logStream) << "\t\t<actionName>" << myAction->getName() << "</actionName>" << Qt::endl;
 
             //-- set the input components
             ComponentList allComps = Application::getAllComponents();
@@ -225,7 +224,7 @@ void ActionState::onEntry(QEvent* event) {
 
             // log inputs
             if (inputComponentNames.size() > 0) {
-                (*logStream) << "\t\t<inputs>" << endl;
+                (*logStream) << "\t\t<inputs>" << Qt::endl;
             }
 
             // search for proper input considering name and type
@@ -244,13 +243,13 @@ void ActionState::onEntry(QEvent* event) {
 
                 if (compIt != allComps.constEnd()) {
                     (*logStream) << "\t\t\t<component name='";
-                    (*logStream) << (*compIt)->getName() << "' type='" << compType << "'/>" << endl;
+                    (*logStream) << (*compIt)->getName() << "' type='" << compType << "'/>" << Qt::endl;
                     inputComps.append((*compIt));
                 }
             }
 
             if (inputComponentNames.size() > 0) {
-                (*logStream) << "\t\t</inputs>" << endl;
+                (*logStream) << "\t\t</inputs>" << Qt::endl;
             }
 
             myAction->setInputComponents(inputComps);
@@ -287,7 +286,7 @@ void ActionState::onEntry(QEvent* event) {
 
             // static properties
             if ((nbStaticProps > 0) || (! propertyNames.isEmpty())) {
-                (*logStream) << "\t\t<parameters>" << endl;
+                (*logStream) << "\t\t<parameters>" << Qt::endl;
 
                 for (int index = 0 ; index < nbStaticProps; index++) {
                     QString staticPropName = myAction->metaObject()->property(index).name();
@@ -296,17 +295,17 @@ void ActionState::onEntry(QEvent* event) {
                         (*logStream) << "\t\t\t<parameter name='";
                         (*logStream) << staticPropName << "' value='";
                         (*logStream) << myAction->property(staticPropName.toStdString().c_str()).toString() ;
-                        (*logStream) << "' static='true'/>" << endl;
+                        (*logStream) << "' static='true'/>" << Qt::endl;
                     }
                 }
 
                 // dynamic properties
                 for (QList<QByteArray>::const_iterator it = propertyNames.constBegin(); it != propertyNames.constEnd(); ++it) {
                     (*logStream) << "\t\t\t<parameter name='";
-                    (*logStream) << (*it) << "' value='" << myAction->property(*it).toString() << "'/>" << endl;
+                    (*logStream) << (*it) << "' value='" << myAction->property(*it).toString() << "'/>" << Qt::endl;
                 }
 
-                (*logStream) << "\t\t</parameters>" << endl;
+                (*logStream) << "\t\t</parameters>" << Qt::endl;
             }
         }
     }
@@ -321,10 +320,10 @@ void ActionState::autoNextExit() {
 void ActionState::onExit(QEvent* event) {
     if (logStream != nullptr) {
         QTime endTime = QTime::currentTime();
-        (*logStream) << "\t\t<!-- exiting " << this->name << " -->" << endl;
-        (*logStream) << "\t\t<endTime>" << endTime.toString("hh:mm:ss:zzz") << "</endTime>" << endl;
-        (*logStream) << "\t\t<timeElapsed unit='ms'>" << (startTime->elapsed()) << "</timeElapsed>" << endl;
-        (*logStream) << "\t</state>" << endl;
+        (*logStream) << "\t\t<!-- exiting " << this->name << " -->" << Qt::endl;
+        (*logStream) << "\t\t<endTime>" << endTime.toString("hh:mm:ss:zzz") << "</endTime>" << Qt::endl;
+        (*logStream) << "\t\t<timeElapsed unit='ms'>" << actionTimer.msecsTo(QTime::currentTime()) << "</timeElapsed>" << Qt::endl;
+        (*logStream) << "\t</state>" << Qt::endl;
     }
 }
 
