@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -117,7 +117,7 @@ protected:
     QDir saveDirectory;
 
     /// To get track of the Action State Machine the duration
-    QTime* startTime;
+    QTime stateMachineTimer;
 
     /// Log stream to write report on logFile
     QTextStream* logStream;
