@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -37,7 +37,7 @@
 ActionStateViewer::ActionStateViewer(QString name) : Viewer(name, Viewer::DOCKED) {
     myWidget = nullptr;
     // empty the list as this is a state viewer, it has nothing to do with Components
-    setComponents(QStringList());
+    setComponentClassNames(QStringList());
 }
 
 // ---------------- getWidget ----------------
