@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -42,8 +42,7 @@ ActionTransition::ActionTransition(QPushButton* sender, const char* signal, QSta
 // --------------- onTransition --------------
 void ActionTransition::onTransition(QEvent* e) {
     if (logStream != nullptr) {
-        startTime = new QTime();
-        startTime->start();
+        transitionTimer = QTime::currentTime();
         auto* asS = dynamic_cast<ActionState*>(sourceState());
         if (asS != nullptr) {
             QString comment;
@@ -56,10 +55,10 @@ void ActionTransition::onTransition(QEvent* e) {
                 comment += " dest: none";
             }
             comment += " -->";
-            (*logStream) << comment << endl;
+            (*logStream) << comment << Qt::endl;
         }
-        (*logStream) << "\t<transition>" << endl;
-        (*logStream) << "\t\t<startTime>" << startTime->toString("hh:mm:ss:zzz") << "</startTime>" << endl;
+        (*logStream) << "\t<transition>" << Qt::endl;
+        (*logStream) << "\t\t<startTime>" << transitionTimer.toString("hh:mm:ss:zzz") << "</startTime>" << Qt::endl;
     }
 
     Action::ApplyStatus status(Action::TRIGGERED);
@@ -76,7 +75,7 @@ void ActionTransition::onTransition(QEvent* e) {
     // Close needed components
     if (! componentsToClose.isEmpty()) {
         if (logStream != nullptr) {
-            (*logStream) << "\t\t<closing>" << endl;
+            (*logStream) << "\t\t<closing>" << Qt::endl;
         }
 
         ComponentList compsToClose;
@@ -112,7 +111,7 @@ void ActionTransition::onTransition(QEvent* e) {
                 if (forceClose) {
                     (*logStream) << "' force='true";
                 }
-                (*logStream) << "'/>" << endl;
+                (*logStream) << "'/>" << Qt::endl;
             }
             if (forceClose) {
                 (*compIt)->setModified(false);
@@ -122,7 +121,7 @@ void ActionTransition::onTransition(QEvent* e) {
         }
 
         if (logStream != nullptr) {
-            (*logStream) << "\t\t</closing>" << endl;
+            (*logStream) << "\t\t</closing>" << Qt::endl;
         }
     }
 
@@ -138,9 +137,9 @@ void ActionTransition::onTransition(QEvent* e) {
     if (logStream != nullptr) {
         QTime endTime = QTime::currentTime();
 
-        (*logStream) << "\t\t<endTime>" << endTime.toString("hh:mm:ss:zzz") << "</endTime>" << endl;
-        (*logStream) << "\t\t<timeElapsed unit='ms'>" << (startTime->elapsed()) << "</timeElapsed>" << endl;
-        (*logStream)  << "\t</transition>" << endl;
+        (*logStream) << "\t\t<endTime>" << endTime.toString("hh:mm:ss:zzz") << "</endTime>" << Qt::endl;
+        (*logStream) << "\t\t<timeElapsed unit='ms'>" << transitionTimer.msecsTo(QTime::currentTime()) << "</timeElapsed>" << Qt::endl;
+        (*logStream)  << "\t</transition>" << Qt::endl;
     }
 }
 
