@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -91,7 +91,7 @@ private:
     QTextStream* logStream;
 
     /// Keep track of time (needed for the log)
-    QTime* startTime;
+    QTime transitionTimer;
 
     /// the button that controls this transition
     QPushButton* myButton;
