@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -52,9 +52,9 @@ Action::ApplyStatus SaveActionState::applyAction() {
     Action::ApplyStatus status(Action::TRIGGERED);
 
     if (logStream != nullptr) {
-        (*logStream) << "\t\t<applyAction>" << endl;
-        (*logStream) << "\t\t\t<name>" << myAction->getName() << "</name>" << endl;
-        (*logStream) << "\t\t\t<inputs>" << endl;
+        (*logStream) << "\t\t<applyAction>" << Qt::endl;
+        (*logStream) << "\t\t\t<name>" << myAction->getName() << "</name>" << Qt::endl;
+        (*logStream) << "\t\t\t<inputs>" << Qt::endl;
     }
 
     // set input components
@@ -111,12 +111,12 @@ Action::ApplyStatus SaveActionState::applyAction() {
 
         if (logStream != NULL) {
             (*logStream) << "\t\t\t\t<component name='";
-            (*logStream) << compDir + "/" + compName + compExt << "' type='" << compType << "'/>" << endl;
+            (*logStream) << compDir + "/" + compName + compExt << "' type='" << compType << "'/>" << Qt::endl;
         }
     }
 
     if (logStream != nullptr) {
-        (*logStream) << "\t\t\t</inputs>" << endl;
+        (*logStream) << "\t\t\t</inputs>" << Qt::endl;
     }
 
 
@@ -133,8 +133,8 @@ Action::ApplyStatus SaveActionState::applyAction() {
     }
 
     if (logStream != nullptr) {
-        (*logStream) << "\t\t\t<status>" << Action::getStatusAsString(status) << "</status>" << endl;
-        (*logStream) << "\t\t</applyAction>" << endl;
+        (*logStream) << "\t\t\t<status>" << Action::getStatusAsString(status) << "</status>" << Qt::endl;
+        (*logStream) << "\t\t</applyAction>" << Qt::endl;
     }
 
     Application::refresh();
