@@ -24,34 +24,38 @@ initTestData() {
     #-- fill test data arrays
     
     # Number of component, action and viewer extensions
-    componentExtensionCount=(   [5.0]=14  [4.1]=14  [4.0]=14  )
-    actionExtensionCount=(      [5.0]=33  [4.1]=27  [4.0]=27  )
-    viewerExtensionCount=(      [5.0]=10                      )
+    componentExtensionCount=( [5.2]=14 [5.1]=14  [5.0]=14  [4.1]=14  [4.0]=14   )
+    actionExtensionCount=(    [5.2]=33 [5.1]=33  [5.0]=33  [4.1]=27  [4.0]=27   )
+    viewerExtensionCount=(    [5.2]=10 [5.1]=10  [5.0]=10                       )
     
     # Number of different file format/extension manages by the component extensions
-    fileExtensionCount=(        [5.0]=37  [4.1]=37  [4.0]=37  )
+    fileExtensionCount=(      [5.2]=37 [5.1]=37  [5.0]=37  [4.1]=37  [4.0]=37   )
     
     # Number of actions provided by the action extensions
-    actionCount=(               [5.0]=111 [4.1]=105 [4.0]=105 )
+    actionCount=(             [5.2]=111 [5.1]=111 [5.0]=111 [4.1]=105 [4.0]=105 )
     
     # Number of viewers managed by the viewer extensions
-    viewerCount=(               [5.0]=13                      )
-
-    #-- Release date
-    releaseDate=(               [5.0]="30 April 2021" \
-                                [4.1]="15 July 2018" \
-                                [4.0]="22 July 2016" \
-                                [3.5]="29 January 2016"
-                                [3.4]="31 October 2014" \
-                                [3.3]="4 March 2014" \
-                                [3.2]="26 June 2013" \
-                                [3.1]="1 March 2013" \
-                                [3.0]="7 July 2012" )
+    viewerCount=(             [5.2]=13 [5.1]=13  [5.0]=13                       )
 
     #-- extensionCount is just the sum of all three extension counts
-    extensionCount=(            [5.0]=$((componentExtensionCount[5.0] + actionExtensionCount[5.0] + viewerExtensionCount[5.0]))
-                                [4.1]=$((componentExtensionCount[4.1] + actionExtensionCount[4.1])) 
-                                [4.0]=$((componentExtensionCount[4.0] + actionExtensionCount[4.0]))  )
+    extensionCount=(          [5.2]=$((componentExtensionCount[5.2] + actionExtensionCount[5.2] + viewerExtensionCount[5.2]))
+                              [5.1]=$((componentExtensionCount[5.1] + actionExtensionCount[5.1] + viewerExtensionCount[5.1]))
+                              [5.0]=$((componentExtensionCount[5.0] + actionExtensionCount[5.0] + viewerExtensionCount[5.0]))
+                              [4.1]=$((componentExtensionCount[4.1] + actionExtensionCount[4.1])) 
+                              [4.0]=$((componentExtensionCount[4.0] + actionExtensionCount[4.0]))  )
+
+    #-- Release date
+    releaseDate=(             [5.2]="not yet released, current development version" \
+                              [5.1]="28 July 2023" \
+                              [5.0]="30 April 2021" \
+                              [4.1]="15 July 2018" \
+                              [4.0]="22 July 2016" \
+                              [3.5]="29 January 2016"
+                              [3.4]="31 October 2014" \
+                              [3.3]="4 March 2014" \
+                              [3.2]="26 June 2013" \
+                              [3.1]="1 March 2013" \
+                              [3.0]="7 July 2012" )
 
 }
 
@@ -75,11 +79,15 @@ cleanup() {
     # backup the current exit status
     currentExitValue=$?
     if [[ "$osName" != "Windows" ]]; then
-        # kill the xfvb
-        kill $xvfbPid    
+        # kill the xfvb if still exist
+        if [ -f /proc/$xvfbPid/status ]; then
+            echo "Killing running xvfb server (pid $xvfbPid)..."
+            kill $xvfbPid
+        fi
     fi
     # cleanup current dir (but not build dir!)
-    if [ "$inBuild" == "0" ] ; then
+    if [ "$inBuild" == "0" ]; then
+        echo "Cleaning up working directory $workingDir..."
         rm -rf $workingDir
     fi
     # use the backup value (otherwise the result of the "rm -rf" command above will
