@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -69,7 +69,7 @@ bool MshExtension::save(Component* component) const {
         return false;
     }
 
-    ofstream mshFile(meshComp->getFileName().toStdString().c_str());
+    std::ofstream mshFile(meshComp->getFileName().toStdString().c_str());
     double xyz[3];
     mshFile << "$NOD" << endl;
     mshFile << ps->GetPoints()->GetNumberOfPoints() << endl;
