@@ -2,7 +2,7 @@
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
-* (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+* (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
 *
 * Visit http://camitk.imag.fr for more information
 *
@@ -87,7 +87,7 @@ bool ObjExtension::save(camitk::Component* component) const {
     cleanFilter->SetInputData(poly);
     cleanFilter->Update();
 
-    ofstream objFile(fileName.toUtf8());
+    std::ofstream objFile(fileName.toUtf8());
     double xyz[3];
     objFile << "# Object 3D file generated by CamiTK" << endl;
     objFile << "# number of vertices : " << cleanFilter->GetOutput()->GetPoints()->GetNumberOfPoints() << endl;
