@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -61,8 +61,6 @@ camitk::Component* OffExtension::open(const QString& fileName) {
 
 // --------------- save -------------------
 bool OffExtension::save(Component* component) const {
-    bool saveOk = true;
-
     vtkSmartPointer<vtkPointSet> ps = component->getPointSet();
 
     if (ps == nullptr || ps->GetNumberOfPoints() == 0 || ps->GetNumberOfCells() == 0) {
@@ -74,7 +72,7 @@ bool OffExtension::save(Component* component) const {
 
     QString offFilename = baseFilename + ".off";
 
-    ofstream offFile(offFilename.toUtf8());
+    std::ofstream offFile(offFilename.toUtf8());
     double xyz[3];
     offFile << "OFF" << endl;
     // write the number of points, cells and edges
@@ -103,13 +101,14 @@ bool OffExtension::save(Component* component) const {
                 offFile << endl;
                 break;
             default:
-                saveOk = false;
-                CAMITK_ERROR("Unsupported cell type (only triangles and quad are supported).")
+                CAMITK_ERROR("Unsupported cell type (only triangles and quads are supported). Aborting.")
+                return false;
                 break;
         }
     }
 
     offFile.close();
 
-    return saveOk;
+    // if it was not stop up to here, everything went fine
+    return true;
 }
