@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -127,7 +127,7 @@ void ActionExtensionGenerator::writeHFile(QString directory) {
         text.replace(QRegExp("@EXTENSIONCLASSNAME@"), className);
         text.replace(QRegExp("@EXTENSIONNAME@"), name);
         text.replace(QRegExp("@EXTENSIONDESCRIPTION@"), this->description);
-        outh << text << endl;
+        outh << text << Qt::endl;
     }
     while (! text.isNull());
     extFileH.close();
@@ -160,7 +160,7 @@ void ActionExtensionGenerator::writeCFile(QString directory) {
         text.replace(QRegExp("@EXTENSIONCLASSNAMELOW@"), className.toLower());
         if (text.contains(QRegExp("@INCLUDEACTIONHEADERS@"))) {
             for (it = actions.constBegin(); it < actions.constEnd(); ++it) {
-                outc << "#include \"" << (*it)->getClassName() << ".h\"" << endl;
+                outc << "#include \"" << (*it)->getClassName() << ".h\"" << Qt::endl;
             }
         }
         else if (text.contains(QRegExp("@BEGIN_REGISTERACTIONS@"))) {
@@ -176,18 +176,18 @@ void ActionExtensionGenerator::writeCFile(QString directory) {
                     text = inc.readLine();
                 }
                 for (int a = 0; a < registerTheAction.size(); a++) {
-                    outc << registerTheAction.at(a) << endl;
+                    outc << registerTheAction.at(a) << Qt::endl;
                 }
             }
             else {
                 while (! text.contains(QRegExp("@ENDREGISTERACTIONS@"))) {
                     text = inc.readLine();
                 }
-                outc << "// You should register your actions here." << endl;
+                outc << "// You should register your actions here." << Qt::endl;
             }
         }
         else {
-            outc << text << endl;
+            outc << text << Qt::endl;
         }
     }
     while (! text.isNull());
