@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -214,7 +214,7 @@ void ActionGenerator::writeHFile(QString directoryName) {
             // Go to the next line...
         }
         else {
-            out << text << endl;
+            out << text << Qt::endl;
         }
     }
     while (! text.isNull());
@@ -271,7 +271,7 @@ void ActionGenerator::writeCFile(QString directoryName) {
         text.replace(QRegExp("@FAMILY@"), family);
         if (text.contains(QRegExp("@ADDITIONAL_INCLUDES@"))) {
             for (QSet<QString>::const_iterator incl = additionalIncludes.constBegin(); incl != additionalIncludes.constEnd(); ++incl) {
-                out << (*incl) << endl;
+                out << (*incl) << Qt::endl;
             }
         }
         else if (text.contains(QRegExp("@IF_NOCOMP@"))) {
@@ -354,7 +354,7 @@ void ActionGenerator::writeCFile(QString directoryName) {
                     }
                 }
                 for (int t = 0; t < addTheTags.size(); t++) {
-                    out << addTheTags.at(t) << endl;
+                    out << addTheTags.at(t) << Qt::endl;
                 }
             }
             else {
@@ -364,7 +364,7 @@ void ActionGenerator::writeCFile(QString directoryName) {
                 if (text.contains("@ELSE_ADDTAG@")) {
                     text = in.readLine();
                     while (! text.contains("@END_ADDTAG@")) {
-                        out << text << endl;
+                        out << text << Qt::endl;
                         text = in.readLine();
                     }
                 }
@@ -375,7 +375,7 @@ void ActionGenerator::writeCFile(QString directoryName) {
             text = in.readLine();
             while (! text.contains(QRegExp("@ENDIF_ADDPROPERTIES@"))) {
                 if (! actionParameters.isEmpty()) {
-                    out << text << endl;
+                    out << text << Qt::endl;
                 }
                 text = in.readLine();
             }
@@ -409,7 +409,7 @@ void ActionGenerator::writeCFile(QString directoryName) {
                     }
                 }
                 for (int p = 0; p < addTheProps.size(); p++) {
-                    out << addTheProps.at(p) << endl;
+                    out << addTheProps.at(p) << Qt::endl;
                 }
             }
             else {
@@ -419,14 +419,14 @@ void ActionGenerator::writeCFile(QString directoryName) {
                 if (text.contains("@ELSE_ADDPROPERTIES@")) {
                     text = in.readLine();
                     while (! text.contains("@END_ADDPROPERTIES@")) {
-                        out << text << endl;
+                        out << text << Qt::endl;
                         text = in.readLine();
                     }
                 }
             }
         }
         else {
-            out << text << endl;
+            out << text << Qt::endl;
         }
     }
 
@@ -465,7 +465,7 @@ void ActionGenerator::writeSpecialItkFile(QString directoryName) {
         text.replace(QRegExp("@LICENCE@"), licence);
         text.replace(QRegExp("@ACTIONCLASSNAME@"), className);
         text.replace(QRegExp("@OUTPUTTYPE@"), itkFilterOutputType);
-        out << text << endl;
+        out << text << Qt::endl;
     }
     while (! text.isNull());
 
