@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -247,7 +247,7 @@ void CepGenerator::generateGlobalCMakeLists() {
         text.replace(QRegExp("@PROJECT_NAME@"), projectNameString);
         text.replace(QRegExp("@CONTACT@"), contactString);
         text.replace(QRegExp("@DESCRIPTION@"), descriptionString);
-        out << text << endl;
+        out << text << Qt::endl;
     }
     while (! text.isNull());
     cmakelistsOutFile.close();
@@ -296,7 +296,7 @@ void CepGenerator::generateCopyright() {
     QString text;
     do {
         text = in.readLine();
-        out << text << endl;
+        out << text << Qt::endl;
     }
     while (! text.isNull());
 
@@ -328,7 +328,7 @@ void CepGenerator::generateReadme() {
 
         do {
             text = in.readLine();
-            out << text << endl;
+            out << text << Qt::endl;
         }
         while (! text.isNull());
     }
