@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -129,7 +129,7 @@ void ComponentExtensionGenerator::writeHFile(QString directory) {
         text.replace(QRegExp("@EXTENSIONCLASSNAME@"), className);
         text.replace(QRegExp("@EXTENSIONNAME@"), this->name);
         text.replace(QRegExp("@EXTENSIONDESCRIPTION@"), this->description);
-        outh << text << endl;
+        outh << text << Qt::endl;
     }
     while (! text.isNull());
     extFileH.close();
@@ -174,14 +174,14 @@ void ComponentExtensionGenerator::writeCFile(QString directory) {
 
         if (text.contains(QRegExp("@INCLUDECOMPONENTSHEADERS@"))) {
             for (it = components.constBegin(); it < components.constEnd(); ++it) {
-                outc << "#include \"" << (*it)->getClassName() << ".h\"" << endl;
+                outc << "#include \"" << (*it)->getClassName() << ".h\"" << Qt::endl;
             }
         }
 
         else {
             if (text.contains(QRegExp("@EXTENSIONSDEF@"))) {
                 for (QStringList::const_iterator suffixe = suffixesList.constBegin(); suffixe != suffixesList.constEnd(); ++suffixe) {
-                    outc << "    ext << \"" << (*suffixe) << "\";" << endl;
+                    outc << "    ext << \"" << (*suffixe) << "\";" << Qt::endl;
                 }
 
             }
@@ -191,7 +191,7 @@ void ComponentExtensionGenerator::writeCFile(QString directory) {
                     if (suffixesList.isEmpty()) {
                         // Copy what is between @IF_NO_SUFFIX@ and @ELSE_IF_ONLY_ONE_SUFFIX@
                         while (! text.contains(QRegExp("@ELSE_IF_ONLY_ONE_SUFFIX@"))) {
-                            outc << text << endl;
+                            outc << text << Qt::endl;
                             text = inc.readLine();
                         }
 
@@ -237,7 +237,7 @@ void ComponentExtensionGenerator::writeCFile(QString directory) {
 
                                 if (text.contains(QRegExp("@EXTENSIONSDEF@"))) {
                                     for (QStringList::const_iterator suffixe = suffixesList.constBegin(); suffixe != suffixesList.constEnd(); ++suffixe) {
-                                        outc << "    ext << \"" << (*suffixe) << "\";" << endl;
+                                        outc << "    ext << \"" << (*suffixe) << "\";" << Qt::endl;
                                     }
                                 }
                                 else {
@@ -246,14 +246,14 @@ void ComponentExtensionGenerator::writeCFile(QString directory) {
                                         for (suffixeIdx = 0; suffixeIdx < suffixesList.size(); suffixeIdx ++) {
                                             QString componentClassName = findComponentClass(suffixesList.at(suffixeIdx));
 
-                                            outc << "    case  " << suffixeIdx << ": " << endl;
-                                            outc << "        component = new " << componentClassName << "(fileName);" << endl;
-                                            outc << "        break;" << endl;
+                                            outc << "    case  " << suffixeIdx << ": " << Qt::endl;
+                                            outc << "        component = new " << componentClassName << "(fileName);" << Qt::endl;
+                                            outc << "        break;" << Qt::endl;
                                         }
                                     }
                                     else {
                                         if (! text.contains(QRegExp("@END_IF_NO_SUFFIX@"))) {
-                                            outc << text << endl;
+                                            outc << text << Qt::endl;
                                         }
                                     }
                                 }
@@ -262,11 +262,11 @@ void ComponentExtensionGenerator::writeCFile(QString directory) {
                     }
 
                     // current line
-                    outc << endl;
+                    outc << Qt::endl;
                 }
 
                 else {
-                    outc << text << endl;
+                    outc << text << Qt::endl;
                 }
             }
         }
@@ -315,7 +315,7 @@ void ComponentExtensionGenerator::generateTestDataFiles(QString directory, QStri
                 return;
             }
             QTextStream outc(&oFile);
-            outc << "// This is an empty test file to test " << componentClassName << " Component" << endl;
+            outc << "// This is an empty test file to test " << componentClassName << " Component" << Qt::endl;
         }
     }
 
