@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -173,7 +173,7 @@ void ComponentGenerator::writeHFile(QString directoryName) {
             // Go to next line...
         }
         else {
-            out << text << endl;
+            out << text << Qt::endl;
         }
 
     }
@@ -224,7 +224,7 @@ void ComponentGenerator::writeCFile(QString directoryName) {
 
         if (text.contains(QRegExp("@ADDITIONAL_INCLUDES@"))) {
             for (QSet<QString>::const_iterator incl = additionalIncludes.constBegin(); incl != additionalIncludes.constEnd(); ++incl) {
-                out << (*incl) << endl;
+                out << (*incl) << Qt::endl;
             }
         }
         else if (text.contains(QRegExp("@IF_NONE@"))) {
@@ -291,7 +291,7 @@ void ComponentGenerator::writeCFile(QString directoryName) {
             text = in.readLine();
             while (! text.contains(QRegExp("@ENDIF_ADDPROPERTIES@"))) {
                 if (! componentProperties.isEmpty()) {
-                    out << text << endl;
+                    out << text << Qt::endl;
                 }
                 text = in.readLine();
             }
@@ -325,7 +325,7 @@ void ComponentGenerator::writeCFile(QString directoryName) {
                     }
                 }
                 for (int p = 0; p < addTheProps.size(); p++) {
-                    out << addTheProps.at(p) << endl;
+                    out << addTheProps.at(p) << Qt::endl;
                 }
             }
             else {
@@ -335,14 +335,14 @@ void ComponentGenerator::writeCFile(QString directoryName) {
                 if (text.contains("@ELSE_ADDPROPERTIES@")) {
                     text = in.readLine();
                     while (! text.contains("@END_ADDPROPERTIES@")) {
-                        out << text << endl;
+                        out << text << Qt::endl;
                         text = in.readLine();
                     }
                 }
             }
         }
         else {
-            out << text << endl;
+            out << text << Qt::endl;
         }
     }
     while (! text.isNull());
