@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -121,7 +121,7 @@ void ExtensionGenerator::generateExtensionCMakeLists(QString directory) {
         text.replace(QRegExp("@NEEDEDACTIONEXT@"), neededActions);
         text.replace(QRegExp("@NEEDEDVIEWEREXT@"), neededViewers);
         text.replace(QRegExp("@EXTENSIONDESCRIPTION@"), this->description);
-        out << text << endl;
+        out << text << Qt::endl;
     }
     while (! text.isNull());
     cmakelistsOutFile.close();
