@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -133,7 +133,7 @@ void LibraryGenerator::generateExtensionCMakeLists(QString directory) {
         text.replace(QRegExp("@NEEDEDCOMPEXT@"), neededComps);
         text.replace(QRegExp("@NEEDEDACTIONEXT@"), neededActions);
         text.replace(QRegExp("@LIBRARYDESCRIPTION@"), this->description);
-        out << text << endl;
+        out << text << Qt::endl;
     }
     while (! text.isNull());
     cmakelistsOutFile.close();
