@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -299,7 +299,7 @@ const QStringList Core::getInstallDirectories(QString suffix, bool exitOnError)
     }
 
     if (dir.empty() && exitOnError) {
-	QString ext=QFileInfo(suffix).completeBaseName();
+        QString ext = QFileInfo(suffix).completeBaseName();
         QString msg = QObject::tr("Installation directory not found: no %1 extensions can be found. Exiting. If you did not install CamiTK, you should at least set your current working directory to CamiTK Community Edition build dir. Note: the current working directory is %2, looking for %3").arg(ext, getCurrentWorkingDir(), suffix);
         qDebug() << msg; // to force show on console
         CAMITK_ERROR_ALT(msg);
@@ -311,12 +311,14 @@ const QStringList Core::getInstallDirectories(QString suffix, bool exitOnError)
 
 // ------------- getExtensionDirectories (static) -----------------
 const QStringList Core::getExtensionDirectories(QString extensionType) {
-    QSet<QString> multiarchInstalledDirectories = getInstallDirectories(QString(Core::libDir) + "/" + QString(Core::shortVersion) + "/" + extensionType).toSet();
+    QStringList installDirectories = getInstallDirectories(QString(Core::libDir) + "/" + QString(Core::shortVersion) + "/" + extensionType);
+    QSet<QString> multiarchInstalledDirectories(installDirectories.begin(), installDirectories.end());
     if (QString(Core::libDir) != "lib") {
         // multiarch installation in "lib/xx" requires checking non-multiarch aware current repositories that uses default "lib/"
-        multiarchInstalledDirectories += getInstallDirectories("lib/" + QString(Core::shortVersion) + "/" + extensionType).toSet();
+        QStringList libInstallDirectories = getInstallDirectories("lib/" + QString(Core::shortVersion) + "/" + extensionType, false);
+        multiarchInstalledDirectories += QSet<QString>(libInstallDirectories.begin(), libInstallDirectories.end());
     }
-    return multiarchInstalledDirectories.toList();
+    return multiarchInstalledDirectories.values();
 }
 
 // ------------- getActionDirectories (static) -----------------
@@ -366,7 +368,7 @@ const QString Core::getGlobalInstallDir() {
             while (process.waitForReadyRead(-1)) {
                 camitkDirectory += process.readAllStandardOutput();
             }
-            camitkDir = QString(camitkDirectory).trimmed();
+            camitkDir.setPath(QString(camitkDirectory).trimmed());
             // if the directory does not exist check CamiTKDir.txt
             processOk = camitkDir.exists();
         }
@@ -378,11 +380,11 @@ const QString Core::getGlobalInstallDir() {
         QFile file(getUserInstallDir() + "/CamiTKDir.txt");
         if (file.exists() && file.open(QIODevice::ReadOnly | QIODevice::Text)) {
             camitkDirectory = file.readLine();
-            camitkDir = QString(camitkDirectory).trimmed();
+            camitkDir.setPath(QString(camitkDirectory).trimmed());
         }
         else {
             // everything failed, use current application directory path (last chance)
-            camitkDir = qApp->applicationDirPath();
+            camitkDir.setPath(qApp->applicationDirPath());
             camitkDir.cdUp();
         }
     }
