@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -438,16 +438,28 @@ ComponentExtension* ExtensionManager::getComponentExtension(QString extOrName) {
 }
 
 // -------------------- getComponentExtensionsList --------------------
-const QList< ComponentExtension* > ExtensionManager::getComponentExtensionsList() {
-    QList< ComponentExtension* > sortedList = getComponentExtensionMap().values().toSet().toList(); // to remove duplicates
+const QList<ComponentExtension* > ExtensionManager::getComponentExtensionsList() {
+    QList<ComponentExtension* > rawList = getComponentExtensionMap().values();
+
+    // remove duplicates
+    QSet<ComponentExtension* > rawSet(rawList.begin(), rawList.end());
+    QList<ComponentExtension* > sortedList = QList<ComponentExtension* >(rawSet.begin(), rawSet.end());
+
+    // sort
     std::sort(sortedList.begin(), sortedList.end(), ExtensionManager::componentExtensionLessThan);
 
     return sortedList;
 }
 
 // -------------------- getDataDirectoryComponentsList --------------------
-const QList< ComponentExtension* > ExtensionManager::getDataDirectoryComponentsList() {
-    QList< ComponentExtension* > sortedList = getDataDirectoryComponentExtensionMap().values().toSet().toList(); // to remove duplicates
+const QList<ComponentExtension* > ExtensionManager::getDataDirectoryComponentsList() {
+    QList<ComponentExtension* > rawList = getDataDirectoryComponentExtensionMap().values();
+
+    // remove duplicates
+    QSet<ComponentExtension* > rawSet(rawList.begin(), rawList.end());
+    QList<ComponentExtension* > sortedList = QList<ComponentExtension* >(rawSet.begin(), rawSet.end());
+
+    // sort
     std::sort(sortedList.begin(), sortedList.end(), ExtensionManager::componentExtensionLessThan);
 
     return sortedList;
@@ -473,7 +485,13 @@ QMap<QString, ActionExtension*>&    ExtensionManager::getActionExtensionMap() {
 
 // -------------------- getActionExtensionsList --------------------
 const QList< ActionExtension* > ExtensionManager::getActionExtensionsList() {
-    QList< ActionExtension* > sortedList = getActionExtensionMap().values().toSet().toList(); // to remove duplicates
+    QList<ActionExtension* > rawList = getActionExtensionMap().values();
+
+    // remove duplicates
+    QSet<ActionExtension* > rawSet(rawList.begin(), rawList.end());
+    QList<ActionExtension* > sortedList = QList<ActionExtension* >(rawSet.begin(), rawSet.end());
+
+    // sort
     std::sort(sortedList.begin(), sortedList.end(), ExtensionManager::actionExtensionLessThan);
 
     return sortedList;
@@ -511,7 +529,13 @@ void camitk::ExtensionManager::unloadAllViewerExtensions() {
 
 // -------------------- getViewerExtensionsList --------------------
 const QList<ViewerExtension*> camitk::ExtensionManager::getViewerExtensionsList() {
-    QList< ViewerExtension* > sortedList = getViewerExtensionMap().values().toSet().toList(); // to remove duplicates
+    QList<ViewerExtension* > rawList = getViewerExtensionMap().values();
+
+    // remove duplicates
+    QSet<ViewerExtension* > rawSet(rawList.begin(), rawList.end());
+    QList<ViewerExtension* > sortedList = QList<ViewerExtension* >(rawSet.begin(), rawSet.end());
+
+    // sort
     std::sort(sortedList.begin(), sortedList.end(), ExtensionManager::viewerExtensionLessThan);
 
     return sortedList;
