@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -37,7 +37,7 @@ namespace camitk {
 // -------------------- constructor --------------------
 Action::Action(ActionExtension* extension) : QObject() {
     this->extension = extension;
-    this->component = "";
+    componentClassName = "";
     qAction = nullptr;
     isEmbedded = true;
     actionWidget = nullptr;
@@ -106,7 +106,12 @@ void Action::setDescription(QString description) {
 
 // -------------------- setComponent --------------------
 void Action::setComponent(QString component) {
-    this->component = component;
+    setComponentClassName(component);
+}
+
+// -------------------- setComponentClassName --------------------
+void Action::setComponentClassName(QString componentClassName) {
+    this->componentClassName = componentClassName;
 }
 
 // -------------------- setFamily --------------------
@@ -152,7 +157,7 @@ void Action::updateTargets() {
 
     foreach (Component* comp, selComp) {
         // check compatibility
-        if (comp->isInstanceOf(this->getComponent())) {
+        if (comp->isInstanceOf(this->getComponentClassName())) {
             targetComponents.append(comp);
         }
     }
@@ -196,7 +201,7 @@ Action::ApplyStatus Action::trigger(QWidget* parent) {
     updateTargets();
 
     //-- if there are some valid targets or if the action is generic
-    if (targetComponents.size() > 0 || getComponent().isEmpty()) {
+    if (targetComponents.size() > 0 || getComponentClassName().isEmpty()) {
         if (isEmbedded) {
             if (parent != nullptr) {
                 // set the widget in the given parent
@@ -244,7 +249,7 @@ Action::ApplyStatus Action::applyAndRegister() {
     this->preProcess();
 
     //-- if there are some valid targets or if the action is generic
-    if (targetComponents.size() > 0 || getComponent().isEmpty()) {
+    if (targetComponents.size() > 0 || getComponentClassName().isEmpty()) {
         CAMITK_TRACE(tr("Applying..."))
         status = apply();
         CAMITK_TRACE(tr("Done. Status: %1").arg(getStatusAsString(status)))
@@ -266,7 +271,7 @@ Action::ApplyStatus Action::applyInPipeline() {
     preProcessInPipeline();
 
     //-- if there are some valid targets or if the action is generic
-    if (targetComponents.size() > 0 || getComponent().isEmpty()) {
+    if (targetComponents.size() > 0 || getComponentClassName().isEmpty()) {
         CAMITK_TRACE(tr("Applying..."))
         status = apply();
         CAMITK_TRACE(tr("Done. Status: %1").arg(getStatusAsString(status)))
@@ -287,7 +292,7 @@ void Action::setInputComponents(ComponentList inputs) {
 
     foreach (Component* comp, inputs) {
         // check compatibility
-        if (comp->isInstanceOf(this->getComponent())) {
+        if (comp->isInstanceOf(this->getComponentClassName())) {
             targetComponents.append(comp);
         }
     }
@@ -298,7 +303,7 @@ void Action::setInputComponent(Component* input) {
     targetComponents.clear();
 
     // check compatibility
-    if (input->isInstanceOf(this->getComponent())) {
+    if (input->isInstanceOf(this->getComponentClassName())) {
         targetComponents.append(input);
     }
 
