@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -54,7 +54,7 @@ class HistoryItem;
  * - extension : the ActionExtension class where to register your action;
  * - name: name of the action;
  * - description: tag used to describe the action (also used for tooltip and whatsThis of the corresponding QAction);
- * - component: the name of the component class on which this action can be applied or "" (default) for generic actions;
+ * - componentClassName: the name of the component class on which this action can be applied or "" (default) for generic actions;
  * - family: families of actions allows one to group different actions of the same kind under one name;
  * - tags: tags is a list of words used to define an action. These words can be used to find an action.
  * - widget: a default widget (instance of ActionWidget) is build by default (see below if this is not what you need);
@@ -65,7 +65,7 @@ class HistoryItem;
  * push buttons...)
  *
  * If the component class is defined (non empty string), an Action is applied on the currently selected components.
- * If there are no component defined (i.e. you specifies setComponent("")), it means that your action does not
+ * If there are no component defined (i.e. you specifies setComponentClassName("")), it means that your action does not
  * need any inputs.
  *
  * Two steps have to be considered when using an action:
@@ -107,7 +107,7 @@ class HistoryItem;
  * and an applyable/revertable ObjectController that allows you to edit/modify properties.
  *
  * \note
- * The recommanded architecture is for the action widget to call the action's apply method.
+ * The recommended architecture is for the action widget to call the action's apply method.
  * The widget should only manage user interaction.
  *
  * Here are some notes about the rest of the properties:
@@ -223,8 +223,8 @@ public:
     /// \enum ApplyStatus describes what happened during the application of an algorithm (i.e. results of the apply method)
     enum ApplyStatus {
         SUCCESS,    ///< everything went according to plan
-        ERROR,      ///< apply() failed : an error occured (usually it means that the apply() was interrupted)
-        WARNING,    ///< some (partial) error occured during the application of the algorithm
+        ERROR,      ///< apply() failed : an error occurred (usually it means that the apply() was interrupted)
+        WARNING,    ///< some (partial) error occurred during the application of the algorithm
         ABORTED,    ///< the action was aborted before completion
         TRIGGERED  ///< the action was triggered only, but not applied
     };
@@ -233,7 +233,7 @@ public:
 #define ERROR CAMITK_WINDOWS_SYSTEM_ERROR_SAFEGUARD
 #endif
 
-    ///@return the QString equivalement of the given status
+    ///@return the QString equivalent of the given status
     static QString getStatusAsString(ApplyStatus);
 
 public slots:
@@ -266,11 +266,11 @@ public slots:
 
 public:
 
-    /// @name Pipeline execuction of the Action
+    /// @name Pipeline execution of the Action
     ///@{
     /** This method encapsulates the apply() method.
      *  It has to be called within a pipeline (a chain of actions), where a
-     *  script or another programm calls setInputComponents() and/or getOutputComponents.
+     *  script or another program calls setInputComponents() and/or getOutputComponents.
      *  It is not needed in the case of graphical interface which trigger the Action's widget
      *  and applies the action on selected components.
      *  When there is no GUI, preProcessInPipeline() and postProcessInPipeline() methods select the right component(s).
@@ -321,9 +321,24 @@ public:
         return description;
     };
 
+    ///@cond
+    /**
+     * TODO CAMITK_API_DEPRECATED. This section list the methods marked as deprecated. They are to be removed in CamiTK 6.0
+     * @deprecated
+     *
+     * DEPRECATED (CamiTK 6.0) -> to be removed
+     * Use getComponentClassName()
+     */
     /// the name of the component class that can be used by this action
+    CAMITK_API_DEPRECATED("Please use getComponentClassName() instead")
     QString getComponent() const {
-        return component;
+        return getComponentClassName();
+    };
+    ///@endcond
+
+    /// the name of the component class that can be used by this action
+    QString getComponentClassName() const {
+        return componentClassName;
     };
 
     /// the name of the family in which this action is associated
@@ -351,7 +366,7 @@ public:
       * - you do not have any widget to control your action (i.e. getWidget() will have to return nullptr),
       * - you do not use the default ActionWidget but another one.
       *
-      * In the second case, it is strongly recommanded to have a code similar to this:
+      * In the second case, it is strongly recommended to have a code similar to this:
       * \code
       * QWidget *MyAction::getWidget() {
       *    // build or update the widget
@@ -386,7 +401,7 @@ public:
     /// auto update properties
     bool getAutoUpdateProperties() const;
 
-    /// are the properties to be udpated every time the user makes a change in the widget (default is false)?
+    /// are the properties to be updated every time the user makes a change in the widget (default is false)?
     void setAutoUpdateProperties(bool);
 
     /** Get a Property given its name
@@ -412,14 +427,14 @@ public:
     /// @{
     /**
      * Change the target frame according to the default frame policy regarding the input's one.
-     * @param input The component refering to for the computation of the frame.
+     * @param input The component referring to for the computation of the frame.
      * @param target The component on which we apply the frame policy.
      */
     void applyTargetPosition(Component* input, Component* target);
 
     /**
      * Change the target frame according to a given frame policy regarding the input's one.
-     * @param input The component refering to for the computation of the frame.
+     * @param input The component referring to for the computation of the frame.
      * @param target The component on which we apply the frame policy.
      * @param policy The frame policy to use on the target.
      */
@@ -428,7 +443,7 @@ public:
 
 protected:
     /** @name Generic action attributes setters
-     *  These methods can not be redefined in subclasses but have to used to ensure name/description unicity
+     *  These methods can not be redefined in subclasses but have to be used to ensure name/description uniqueness
      *  among CamiTK.
      */
     /// @{
@@ -438,8 +453,21 @@ protected:
     /// the description of the action
     void setDescription(QString description);
 
-    /// the name of the component class that can be used by this action
+    ///@cond
+    /**
+     * TODO CAMITK_API_DEPRECATED. This section list the methods marked as deprecated. They are to be removed in CamiTK 6.0
+     * @deprecated
+     *
+     * DEPRECATED (CamiTK 6.0) -> to be removed
+     * Use setComponentClassName(QString)
+     */
+    /// set the name of the component class that can be used by this action
+    CAMITK_API_DEPRECATED("Please use setComponentClassName(QString componentClassName) instead")
     void setComponent(QString component);
+    ///@endcond
+
+    /// set the name of the component class that can be used by this action
+    void setComponentClassName(QString componentClassName);
 
     /// the name of the family in which this action is associated
     void setFamily(QString family);
@@ -455,21 +483,17 @@ protected:
 
     /// the action widget
     QWidget* actionWidget;
-
-
     ///@}
 
-
-
 private:
     /// the name of the action
     QString name;
 
-    /// the descriptionof the action
+    /// the description of the action
     QString description;
 
     /// the name of the component class that can be used by this action
-    QString component;
+    QString componentClassName;
 
     /// the name of the family in which this action is associated
     QString family;
@@ -525,7 +549,7 @@ private:
 
     /**
      * Save the number of top level components loaded in memory before applying the action.
-     * This allows one to deduce the number of created / deleted components lauching the action.
+     * This allows one to deduce the number of created / deleted components launching the action.
      */
     void preProcess();
 
@@ -536,7 +560,7 @@ private:
     void postProcess();
     ///@}
 
-    /// @name Pipeline execuction of the Action
+    /// @name Pipeline execution of the Action
     ///@{
     /**
      * In case of a pipeline application of the Action (i.e. a chain of actions with no gui),
