@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -177,7 +177,7 @@ Application::Application(QString name, int& theArgc, char** theArgv, bool autolo
     //-- load all property values from the settings
     propertyObject->loadFromSettings(Application::getName() + ".Application");
 
-    //-- Get notified (in evenFilter method) everytime one of the property is modified
+    //-- Get notified (in evenFilter method) every time one of the property is modified
     // All event filter on the property object are delegated to the Application class
     // @see eventFilter()
     propertyObject->installEventFilter(this);
@@ -818,14 +818,14 @@ ActionList Application::getActions(Component* component) {
         QStringList componentHierarchy = component->getHierarchy();
 
         foreach (Action* currentAct, Application::getActions()) {
-            if (componentHierarchy.contains(currentAct->getComponent())) {
+            if (componentHierarchy.contains(currentAct->getComponentClassName())) {
                 actions.insert(currentAct);
             }
         }
     }
     else {
         foreach (Action* currentAct, Application::getActions()) {
-            if (currentAct->getComponent().isEmpty()) {
+            if (currentAct->getComponentClassName().isEmpty()) {
                 actions.insert(currentAct);
             }
         }
@@ -844,7 +844,8 @@ ActionList Application::getActions(ComponentList cList) {
         ActionSet actions;
 
         foreach (Component* currentComp, cList) {
-            actions += getActions(currentComp).toSet();
+            ActionList listOfCompatibleActions = getActions(currentComp);
+            actions += ActionSet(listOfCompatibleActions.begin(), listOfCompatibleActions.end());
         }
 
         return sort(actions);
@@ -936,7 +937,7 @@ ViewerList Application::getViewers(Component* component) {
         QStringList componentHierarchy = component->getHierarchy();
 
         foreach (Viewer* currentViewer, Application::getViewers()) {
-            foreach (QString compType, currentViewer->getComponents()) {
+            foreach (QString compType, currentViewer->getComponentClassNames()) {
                 if (componentHierarchy.contains(compType)) {
                     viewers.insert(currentViewer);
                 }
@@ -945,7 +946,7 @@ ViewerList Application::getViewers(Component* component) {
     }
     else {
         foreach (Viewer* currentViewer, Application::getViewers()) {
-            foreach (QString compType, currentViewer->getComponents()) {
+            foreach (QString compType, currentViewer->getComponentClassNames()) {
                 if (compType.isEmpty()) {
                     viewers.insert(currentViewer);
                 }
@@ -1171,7 +1172,7 @@ void Application::saveHistoryAsSXML() {
     // Description of the pipeline
     QDomElement initializeElt_desc = doc.createElement("camitk:description");
     initializeElt_onState.appendChild(initializeElt_desc);
-    // create the pipeline description that will be filled whilel processing the history items.
+    // create the pipeline description that will be filled while processing the history items.
     QString pipelineDescription = "This pipeline will process several actions on the input component(s): <br /> <ul>";
     // Transition
     QDomElement initializeElt_transition = doc.createElement("transition");
@@ -1184,7 +1185,7 @@ void Application::saveHistoryAsSXML() {
     // by the action state machine
     QList<HistoryComponent> allCreatedComponents;
 
-    // Main loop accross the different actions in the history
+    // Main loop across the different actions in the history
     for (int i = 0; i < Application::getHistory().size(); i++) {
         // Get the current history element, i.e. the action of the pipeline with its parameters
         HistoryItem historyItem = Application::getHistory().at(i);
@@ -1320,7 +1321,7 @@ void Application::saveHistoryAsSXML() {
             }
             else {   // Back to previous state and delete optional created component in memory
                 backTransitionElement.setAttribute("target", "Action " + QString::number(i));
-                // Verify that previsous element has not created components in memory
+                // Verify that previous element has not created components in memory
                 HistoryItem previousItem = Application::getHistory().at(i - 1);
 
                 if (!previousItem.getOutputHistoryComponents().isEmpty()) {
