@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -339,7 +339,7 @@ void MainWindow::refresh() {
             // When an action is triggered, only the viewer that are interested in viewing
             // action should be refreshed, the other viewers should not be involved.
             if (Application::getTriggeredAction() != nullptr) {
-                if (v->getComponents().isEmpty()) {
+                if (v->getComponentClassNames().isEmpty()) {
                     // action viewer(s)
                     v->refresh();
                 }
