@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -191,7 +191,7 @@ void SettingsDialog::updateActionExtensionList() {
             Action* action = ae->getActions().at(i);
             QPixmap actionIcon = action->getIcon();
             myUI->actionExtensionList->setItem(actionId, 0, new QTableWidgetItem((userActions.contains(ae->getLocation()) ? QPixmap(":/user") : ((actionIcon.isNull()) ? QPixmap(":/camiTKIcon") : actionIcon)), action->getName()));
-            myUI->actionExtensionList->setItem(actionId, 1, new QTableWidgetItem(action->getComponent()));
+            myUI->actionExtensionList->setItem(actionId, 1, new QTableWidgetItem(action->getComponentClassName()));
             myUI->actionExtensionList->setItem(actionId, 2, new QTableWidgetItem(ae->getLocation()));
             actionId++;
         }
