@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -350,7 +350,7 @@ QMenu* Component::getActionMenu() {
         //-- create one sub menu per family (unless there is only one action)
         for (const QSet<Action*>& familySet : qAsConst(familyMap)) {
             // sort actions by name
-            ActionList familyList = familySet.toList();
+            ActionList familyList = familySet.values();
             std::sort(familyList.begin(), familyList.end(), actionLessThan);
 
             if (familyList.size() >= 1) {
