@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -291,8 +291,15 @@ public:
       */
     virtual void setGlyphType(const GlyphTypes type, const double size = 0.0) = 0;
 
-    /// set the lines as tubes (<b>works only for vtkDataSet representation that contains lines</b>)
-    virtual void setLinesAsTubes(bool) = 0;
+    /** Set the lines as tubes (<b>works only for vtkDataSet representation that contains lines</b>)
+     * @param isTubes activate tube representation of lines
+     * @param radiusFromLength radius of tubes is computed as a proportion of line length
+     * @param radiusFactor radius of tubes will be : radiusFactor*lineLength if radiusFromLength is true, radiusFactor if it is false
+     * @param numberOfSides Number of sides of the tubes
+     */
+    virtual void setLinesAsTubes(bool isTubes = true, bool radiusFromLength = true, double radiusFactor = 1.0 / 40.0, int numberOfSides = 5) = 0;
+
+    virtual void setColorMode(int vtkColorMode = VTK_COLOR_MODE_DEFAULT) = 0;
 
     ///@}
 };
