@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -97,7 +97,7 @@ void Property::setEnumTypeName(QString nameOfTheEnum, QObject* objectDeclaringTh
     // loop over the enum type, get the key value as string and beautify it
     for (int i = 0; i < enumType.keyCount(); i++) {
         // capitalize every word and replace "_" by space
-        QStringList tokens = QString(enumType.key(i)).split('_', QString::SkipEmptyParts);
+        QStringList tokens = QString(enumType.key(i)).split(QLatin1Char('_'), Qt::SkipEmptyParts);
         for (int j = 0; j < tokens.size(); ++j) {
             tokens[j] = tokens[j].toLower();
             tokens[j].replace(0, 1, tokens[j][0].toUpper());
