@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -106,7 +106,7 @@ QVariant PropertyObject::getPropertyValue(const QString name) {
 // ---------------------- toCamelCase ------------------
 QString PropertyObject::toCamelCase(const QString& s) {
     // split lowercased word separated by space into parts
-    QStringList parts = s.toLower().split(' ', QString::SkipEmptyParts);
+    QStringList parts = s.toLower().split(QLatin1Char(' '), Qt::SkipEmptyParts);
     // capitalize firt letter of every word (but not the first word)
     for (int i = 1; i < parts.size(); ++i) {
         parts[i].replace(0, 1, parts[i][0].toUpper());
