@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -214,6 +214,12 @@ public slots:
     /// set the backface culling mode (default is true).
     void setBackfaceCulling(bool);
 
+    /** @name Viewing/Interaction Property
+     */
+    ///@{
+    /// set the FXAA antialiasing mode (default is false).
+    void setFxaaAntialiasing(bool);
+
     /// visibility of the screenshot in slice viewers
     void setScreenshotAction(bool);
 
@@ -427,6 +433,9 @@ protected:
     /// back face culling
     QAction* toggleBackfaceCullingAction;
 
+    /// FXAA antialiasing
+    QAction* toggleFxaaAntialiasingAction;
+
     /// visibility of the screenshot action in the side toolbar of slice viewer
     QAction* toggleScreenshotAction;
 
@@ -522,6 +531,11 @@ protected:
      */
     Property* backfaceCullingProperty;
 
+    /**
+     * Property that tells whether the viewer uses the backface culling option or not.
+     */
+    Property* fxaaAntialiasingProperty;
+
     /**
      * Property that tells whether the screenshot action is visible or not.
      */
