@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -49,7 +49,7 @@ Viewer::Viewer(QString name, ViewerType type): QObject() {
 
     toolbarVisibility = true;
 
-    components << "Component";
+    componentClassNames << "Component";
 }
 
 //---------------------- destructor ------------------------
@@ -69,12 +69,22 @@ QPixmap Viewer::getIcon() {
 
 // -------------------- setComponents --------------------
 void Viewer::setComponents(QStringList components) {
-    this->components = components;
+    setComponentClassNames(components);
+}
+
+// -------------------- setComponentClassNames --------------------
+void Viewer::setComponentClassNames(QStringList componentClassNames) {
+    this->componentClassNames = componentClassNames;
 }
 
 // -------------------- getComponents --------------------
 QStringList Viewer::getComponents() {
-    return components;
+    return getComponentClassNames();
+}
+
+// -------------------- getComponentClassNames --------------------
+QStringList Viewer::getComponentClassNames() {
+    return componentClassNames;
 }
 
 // -------------------- setDescription --------------------
