@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -71,7 +71,7 @@ class ViewerDockStyle;
   * is modified.
   *
   * If your viewer does not view components (for instance, in the very rare/special case it views actions),
-  * then you need to call the setComponents(...) method with an empty list.
+  * then you need to call the setComponentClassNames(...) method with an empty list.
   * An empty list means that this viewer is going to be also notified/refreshed every time the
   * current selected action is changed (i.e., anytime an action is triggered)
   *
@@ -116,7 +116,7 @@ class ViewerDockStyle;
   *
   * FooBarViewer* fooBarViewer = dynamic_cast<FooBarViewer*>(Application::getViewer("Foo Bar Viewer"));
   * if (fooBarViewer != nullptr) {
-  *    // everything is ok, the FooBar viewer extension is available, add it to the right docker, not visibile by default
+  *    // everything is ok, the FooBar viewer extension is available, add it to the right docker, not visible by default
   *    addDockViewer(Qt::RightDockWidgetArea, fooBarViewer);
   *    showDockViewer(fooBarViewer, false);
   * }
@@ -255,7 +255,7 @@ public:
     void setVisible(bool);
 
     /** set the visibility of the toolbar in the main window (true by default).
-      * If the visibility is set to false, the next call to setCentralViewer(..) or addDockViwer(...) will remove it
+      * If the visibility is set to false, the next call to setCentralViewer(..) or addDockViewer(...) will remove it
       */
     void setToolBarVisibility(bool);
 
@@ -265,9 +265,21 @@ public:
     /// get the viewer icon
     virtual QPixmap getIcon();
 
+    ///@cond
+    /**
+     * TODO CAMITK_API_DEPRECATED. This section list the methods marked as deprecated. They are to be removed in CamiTK 6.0
+     * @deprecated
+     *
+     * DEPRECATED (CamiTK 6.0) -> to be removed
+     * Please use getComponentClassNames() instead
+     */
     /// get the list of Component class manages by this viewer
     /// (default is set to "Component", i.e. all type of Component)
-    QStringList getComponents();
+    CAMITK_API_DEPRECATED("Please use getComponentClassNames() instead") QStringList getComponents();
+    ///@endcond
+    /// get the list of Component class manages by this viewer
+    /// (default is set to "Component", i.e. all type of Component)
+    QStringList getComponentClassNames();
 
 signals:
 
@@ -296,9 +308,21 @@ protected:
     /// set the default icon for the viewer extension
     void setIcon(QPixmap icon);
 
+    ///@cond
+    /**
+     * TODO CAMITK_API_DEPRECATED. This section list the methods marked as deprecated. They are to be removed in CamiTK 6.0
+     * @deprecated
+     *
+     * DEPRECATED (CamiTK 6.0) -> to be removed
+     * Please use setComponentClassNames() instead
+     */
     /// set the list of component class names managed by this viewer
     /// \note Default is set to "Component" (all type of components)
-    void setComponents(QStringList);
+    CAMITK_API_DEPRECATED("Please use setComponentClassNames() instead") void setComponents(QStringList);
+    ///@endcond
+    /// set the list of component class names managed by this viewer
+    /// \note Default is set to "Component" (all type of components)
+    void setComponentClassNames(QStringList);
 
     /// set the viewer's description
     void setDescription(QString);
@@ -319,8 +343,8 @@ private:
     /// the style for the dock widget
     ViewerDockStyle* dockWidgetStyle;
 
-    /// list of Component class name managed by this viewer
-    QStringList components;
+    /// list of Component class names managed by this viewer
+    QStringList componentClassNames;
 
     /// this viewer's layout
     ViewerType type;
