@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -36,7 +36,7 @@ ComputeNeighborValueAction::ComputeNeighborValueAction(ActionExtension* extensio
     // Setting name, description and input component
     setName(tr("Compute Average Neighbor Value"));
     setDescription("Compute the average voxels value in the neiborhoods of the selected voxel. Show results on the log console.");
-    setComponent("ImageComponent");
+    setComponentClassName("ImageComponent");
 
     // Setting classification family and tags
     setFamily(tr("Tutorial"));
