@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -39,7 +39,7 @@ ImagePicking::ImagePicking(ActionExtension* extension) : Action(extension) {
     setName("Basic Image Picking");
     // NOTE try to call setEmbedded(false) to see the difference
     setDescription("Tutorial action that retrieve pixel information from the image");
-    setComponent("ImageComponent");
+    setComponentClassName("ImageComponent");
 
     setFamily("Tutorial");
     addTag("Picking");
