@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -41,7 +41,7 @@ EnumPropertyExample::EnumPropertyExample(ActionExtension* extension) : Action(ex
     //-- Setting name, description and input component
     setName("Enum Property Example");
     setDescription("Demonstrates how to add an enum parameters in an action. Show the information on the log console.");
-    setComponent("");
+    setComponentClassName("");
 
     //-- Setting classification family and tags
     setFamily("Tutorial");
