@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -38,7 +38,7 @@ PropAction::PropAction(ActionExtension* extension) : Action(extension) {
     // Setting name, description and input component
     setName("Add Lots Of Properties");
     setDescription("Add lots of dynamic property to the currently selected component.");
-    setComponent("Component");
+    setComponentClassName("Component");
 
     // Setting classification family and tags
     setFamily("Tutorial");
