@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -38,7 +38,7 @@ ComputeSelectionBarycenter::ComputeSelectionBarycenter(ActionExtension* extensio
     // Setting name, description and input component
     setName("Compute Selection Barycenter");
     setDescription("This action demonstrates how to compute the barycenter of the currently selected mesh nodes");
-    setComponent("MeshComponent");
+    setComponentClassName("MeshComponent");
 
     // Setting classification family and tags
     setFamily("Tutorial");
