@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -39,7 +39,7 @@ WorkingWhenSleepingRandom::WorkingWhenSleepingRandom(ActionExtension* extension)
     // Setting name, description and input component
     setName("Working When Sleeping (Random)");
     setDescription("This action generates a random exploration of slice sagittal, coronal and axial viewers.");
-    setComponent("ImageComponent");
+    setComponentClassName("ImageComponent");
 
     // Setting classification family and tags
     setFamily("Tutorial");
