@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -78,7 +78,7 @@ FancyMainWindow::FancyMainWindow() : MainWindow("Fancy") {
         if (sliceViewer != nullptr) {
             sliceViewer->setSideFrameVisible(false);
             sliceViewer->setGradientBackground(false);
-            sliceViewer->setBackgroundColor(ui.dial->palette().background().color());
+            sliceViewer->setBackgroundColor(ui.dial->palette().window().color());
         }
         else {
             CAMITK_ERROR(tr("Cannot find \"%1\". This viewer is mandatory for running camitk-fancy.").arg(viewerName))
@@ -93,7 +93,7 @@ FancyMainWindow::FancyMainWindow() : MainWindow("Fancy") {
     viewer3D->setEmbedder(ui.viewer3DLayout);
     viewer3D->setSideFrameVisible(false);
     viewer3D->setGradientBackground(false);
-    viewer3D->setBackgroundColor(ui.dial->palette().background().color());
+    viewer3D->setBackgroundColor(ui.dial->palette().window().color());
     viewer3D->getToolBar()->hide();
 
     updateAngleSlider(ui.xAngledial, ui.xAngleValue);
